# PIQTEC

**THIS PACKAGE IS WORK IN PROGRESS**

IQtec is a small smart-home vendor based in the Czech Republic. 
This package is an unofficial python interface intended to be further used in a Home Assistant integration.
The functionality of the API this package relies on is reverse engineered without any access to official
documentation, your mileage may vary. I am not even sure, that the API calls are universal...


